@@ -1,6 +1,6 @@
 package Dist::Zilla::App::Command::gh;
 {
-  $Dist::Zilla::App::Command::gh::VERSION = '0.31';
+  $Dist::Zilla::App::Command::gh::VERSION = '0.32';
 }
 
 use feature 'switch';
@@ -16,7 +16,7 @@ Dist::Zilla::App::Command::gh - Use the GitHub plugins from the command-line
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -32,6 +32,14 @@ sub abstract    { 'use the GitHub plugins from the command-line' }
 sub description { 'Use the GitHub plugins from the command-line' }
 sub usage_desc  { '%c %o [ update | create [<repository>] ]' }
 
+sub opt_spec {
+	[ 'profile|p=s',  'name of the profile to use',
+		{ default => 'default' }  ],
+
+	[ 'provider|P=s', 'name of the profile provider to use',
+		{ default => 'Default' }  ],
+}
+
 sub execute {
 	my ($self, $opt, $arg) = @_;
 
@@ -46,7 +54,7 @@ sub execute {
 
 			my $minter = Dist::Zilla::Dist::Minter
 				-> _new_from_profile(
-				[ 'Default', 'default' ], {
+				[ $opt -> provider, $opt -> profile ], {
 					chrome => $self -> app -> chrome,
 					name   => $zilla -> name,
 				},
